# UMIRobot Python [![Python package](https://github.com/mmmarinho/umirobot-py/actions/workflows/python-package.yml/badge.svg)](https://github.com/mmmarinho/umirobot-py/actions/workflows/python-package.yml)[![PyPI version](https://badge.fury.io/py/umirobot.svg)](https://badge.fury.io/py/umirobot) 

The Python package to interact with the UMIRobot.

Citation:

```bibtex
@misc{marinho2022umirobot,
  author       = {Marinho, M. M. and Lin, H. and Zhao, J.},
  title        = {UMIRobot: An Open-{Software, Hardware} Low-Cost Robotic Manipulator for Education},
  booktitle    = {2023 IEEE/RSJ International Conference on Intelligent Robots and Systems (IROS)},
  year         = {2023},
  month        = oct,
  organization = {IEEE},
  custom_type  = {2. International Conference Paper},
  pages        = {1--8},
  note         = {Accepted for publication.},
  url          = {https://arxiv.org/pdf/2302.05567},
  url_code     = {https://github.com/mmmarinho/umirobot-py},
  url_website  = {https://mmmarinho.github.io/UMIRobot/}
}

```

## General User - GUI Version

![スクリーンショット 2022-06-24 9 08 03](https://user-images.githubusercontent.com/46012516/175437004-3428715e-1da5-4f81-aee8-91eb4db01af7.png)

Download the latest binaries at 

- https://github.com/mmmarinho/umirobot-py/releases/latest

and run it.

### Tested on:
- Windows 10/11
- MacOS (Intel/M1)

## Programmer

**_NOTE:_**  The package is only compatible with Python >= 3.8.

### Installation

Use `pip` to install the package. Dependencies will be automatically installed.

`python -m pip install umirobot`

### Upgrade

`python -m pip install umirobot --upgrade`

### Usage

You can run the GUI as follows

`python -m umirobot`

For more advanced usage, see

- https://github.com/mmmarinho/umirobot

